# PytorchUtils

This is a package designed for rapid prototyping of a deep learning project using [MONAI](https://github.com/Project-MONAI/MONAI) & [PyTorch Lightning](https://github.com/PyTorchLightning/pytorch-lightning).  

**Use with caution!**  
*Intended for personal use.*
